# delapphelper - delapp helper

## Contributing

Please read [CONTRIBUTING.md](https://github.com/grindsa/delstat_scraper/blob/main/CONTRIBUTING.md) for details on my code of conduct, and the process for submitting pull requests.
Please note that I have a life besides programming. Thus, expect a delay in answering.

## License

This project is licensed under the GPLv3 - see the [LICENSE.md](https://github.com/grindsa/dkb-robo/blob/master/LICENSE) file for details
